Django Class Based Views
========================

This is Django Class Based Views taken from Django 1.3-alpha1. Replace all the
references from ``django.views.generic`` to ``cbv`` in the documentation.

`Django Class Based Views Docs <http://docs.djangoproject.com/en/dev/topics/class-based-views/>`_

